import { RouteRecordRaw } from 'vue-router';

export const dynamicRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        redirect: '/home',
        meta: {
            isKeepAlive: false
        },
        children: [
            {
                path: '/test',
                name: 'test',
                component: () => import('/@/views/test/index.vue'),
                meta: {
                    title: '测试',
                    isLink: '',
                    isHide: false,
                    isKeepAlive: true,
                    isAffix: true,
                    isIframe: false,
                    roles: ['admin', 'common'],
                    icon: 'iconfont icon-shouye',
                },
            },
        ]
    }
];

export const notFoundAndNoPower = [
    {
        path: '/:path(.*)*',
        name: 'notFound',
        component: () => import('/@/views/error/404.vue'),
        meta: {
            title: 'message.staticRoutes.notFound',
            isHide: true
        }
    },
    {
        path: '/401',
        name: 'noPower',
        component: () => import('/@/views/error/401.vue'),
        meta: {
            title: 'message.staticRoutes.noPower',
            isHide: true
        }
    }
];

export const staticRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        meta: {
            title: '布局界面'
        },
        children: [
            // 请不要往这里 `children` 中添加内容，此内容为了防止 No match found for location with path "xxx" 问题
            ...notFoundAndNoPower
        ]
    },
    {
        path: '/login',
        name: 'login',
        component: () => import('/@/views/loginPage/loginPage.vue'),
        meta: {
            title: '登录'
        }
    }
];
